/* HISTORY:
 * 0.2 First public version. No support for platform other than *-ncurses.
 * 0.3
 * - ported to MS-DOS and MS-Windows 9x/NT/2000. Tested using the
 * following compilers: DJGPP (w/ and w/o PDCurses 2.2), MSVC++ 6 (w/o
 * curses), Cygwin gcc (w/ and w/o ncurses 5.2);
 * - added "twitecho" support.
 * 0.3.1
 * - output pretty formatting (see dupchar() and related);
 * - "twitdate" support.
 * 0.3.2
 * - added Makefile.lnx to the program distribution ;)
 * - some stuff moved to gedtwit.h
 * - if twitlist doesn`t exist, we append our signature after
 * creating a new file
 * - corrected output format
 * 0.3.3
 * - some minor changes
 * 0.3.4
 * - some minor changes
 */

#include <stdio.h>
#include <string.h>
#include <malloc.h>

#ifdef WITH_CURSES
#include <curses.h>
#endif /* WITH_CURSES */

#include "gedtwit.h"

#ifdef WITH_CURSES
WINDOW *wtwitdesc;
#endif

int absolute(int number)
{
    if(number>=0) {
	return number;
    } else {
	return -number;
    }
}

int multichar(char todup, char *buf, unsigned int howmany)
{
    int n;
    howmany=absolute(howmany);
    for(n=0;n<howmany;++n) {
	buf[n]=todup;
    }
    buf[howmany]='\0';
    return 0;
}

int stripnetname(char *ftnaddr)
{
    int i;
    for(i=strlen(ftnaddr)-1;i>=0;--i) {
	if(ftnaddr[i]=='@') {
	    ftnaddr[i]='\0';
	    break;
	}
    }
    return 0;
}

int newtwitlst(char *twitdate) {

    FILE *fhdrPtr;

    if ((fhdrPtr = fopen(TWITLIST, "r")) == NULL) {
	if ((fhdrPtr = fopen(TWITLIST, "a")) == NULL) {
	    perror("cannot open twitlist-file");
	    return 1;
	} else {
	    fprintf(fhdrPtr,
		    "; This twitlist was generated at %s with %s\n"
		    "; " COPYRIGHT,
		    twitdate, PROGNAME);
	    fclose(fhdrPtr);
	}
    }
    return 0;
}

int addtofile(char *twitdesc, char *twitname, char *twitaddr,
	      char *echotag, char *twitdate) {
    
    FILE *fPtr;
    int i;
    char *spaces1=(char *)malloc(50);
    char *spaces2=(char *)malloc(50);

    spaces1[0]='\0';
    spaces2[0]='\0';
    
    if ((fPtr = fopen(TWITLIST, "a")) == NULL) {
	perror("cannot open twitlist-file");
	return 1;
    }
    else {
	i=strlen(twitname)-strlen(twitaddr);
	
	if(i<0) {
	    multichar(' ', spaces2, i);
	} else {
	    multichar(' ', spaces1, i);
	}
	
	fprintf(fPtr,
		";\n"
		"; %s, %s:\n"
		"twitname %s %s; %s\n"
		"twitname %s %s\n",
		echotag, twitdate,
		twitname, spaces2, twitdesc,
		twitaddr, spaces1);
	fclose(fPtr);
    }
    return 0;
}

int chomp(char *str) {
    int i;
    for(i=strlen(str)-1;i>=0;--i) {
	switch(str[i]) {
	case '\n':
	    str[i]='\0';
	    break;
	case '\r':
	    str[i]='\0';
	    break;
	default:
	    goto exit_for;
	    break;
	}
    }
exit_for:
    return 0;
}

int
usage() {
    fprintf(stderr, "\n" PROGNAME " (Compilation date: %s %s)\n"
	    COPYRIGHT
	    "\nusage: gedtwit \"<name>\" <address> <echotag> \"<date>\"\n\n", __DATE__, __TIME__
	);
    return 0;
}

int main(int argc, char *argv[])
{
    char desc[80];
#ifdef WITH_CURSES
    char windowheader[80];
#endif

    if (argc != 5) {
	usage();
	return 1;
    }
    stripnetname(argv[2]);
    
#ifdef WITH_CURSES
    initscr();
    start_color();
    
    init_pair(1,COLOR_CYAN,COLOR_BLUE);
    refresh();
    
    wtwitdesc = newwin(3,COLS-4,LINES-15,2);
    wbkgd(wtwitdesc, A_BOLD | COLOR_PAIR(1));
    werase(wtwitdesc);
    box(wtwitdesc,0,0);
    sprintf(windowheader, " " PROGNAME ", %s (%s) ", argv[1], argv[2]);
    mvwprintw(wtwitdesc, 0, 1, windowheader);
#else /* WITH_CURSES */
    printf(PROGNAME "\n");
#endif /* WITH_CURSES */

#ifdef WITH_CURSES
    wrefresh(wtwitdesc);
    
    mvwprintw(wtwitdesc,1,2,"");
    curs_set(1);
    echo();
    wrefresh(wtwitdesc);

    wgetstr(wtwitdesc, desc);
#else /* WITH_CURSES */
    printf("Description for %s (%s)? ", argv[1], argv[2]);
    fflush(stdout);
    fgets(desc, sizeof(desc), stdin);
    chomp(desc);
#endif /* WITH_CURSES */

    newtwitlst(argv[4]);
    addtofile(desc, argv[1], argv[2], argv[3], argv[4]);
#ifdef WITH_CURSES   
    clear();
    refresh();
    endwin();
#endif /* WITH_CURSES */

    return 0;

}
